@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KLEOPATRA_COMMANDS_IMPORTCERTIFICATEFROMPIVCARDCOMMAND_H
-#define KLEOPATRA_COMMANDS_IMPORTCERTIFICATEFROMPIVCARDCOMMAND_H
+#pragma once
 
 #include "cardcommand.h"
 
@@ -21,7 +20,7 @@ class ImportCertificateFromPIVCardCommand : public CardCommand
 {
     Q_OBJECT
 public:
-    ImportCertificateFromPIVCardCommand(const std::string& cardSlot, const std::string &serialno);
+    ImportCertificateFromPIVCardCommand(const std::string &cardSlot, const std::string &serialno, QWidget *parent = nullptr);
     ~ImportCertificateFromPIVCardCommand() override;
 
 private:
@@ -36,5 +35,3 @@ private:
 
 }
 }
-
-#endif /* KLEOPATRA_COMMANDS_IMPORTCERTIFICATEFROMPIVCARDCOMMAND_H */
