@@ -11,7 +11,7 @@
 
 #include <QWidget>
 
-#include <utils/pimpl_ptr.h>
+#include <memory>
 
 class KGuiItem;
 
@@ -61,16 +61,13 @@ Q_SIGNALS:
     void windowTitleChanged(const QString &title);
 
 protected:
-
     virtual void onNext();
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 }
 }
 }
-
-
