@@ -11,8 +11,7 @@
 
 #include <QDialog>
 
-#include <utils/pimpl_ptr.h>
-
+#include <memory>
 #include <vector>
 
 namespace GpgME
@@ -41,7 +40,7 @@ public:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 }
